@@ -1,6 +1,9 @@
 #!/usr/bin/env python3
 # -*- coding: future_fstrings -*-
 
+"""
+Wordpress script
+"""
 
 from db_sync_tool.utility import mode, system, helper
 
@@ -17,7 +20,8 @@ def check_configuration(client):
         'name': get_database_setting(client, 'DB_NAME', system.config[client]['path']),
         'host': get_database_setting(client, 'DB_HOST', system.config[client]['path']),
         'password': get_database_setting(client, 'DB_PASSWORD', system.config[client]['path']),
-        'port': get_database_setting(client, 'DB_PORT', system.config[client]['path']) if get_database_setting(client, 'DB_PORT', system.config[client]['path']) != '' else 3306,
+        'port': get_database_setting(client, 'DB_PORT', system.config[client]['path'])
+        if get_database_setting(client, 'DB_PORT', system.config[client]['path']) != '' else 3306,
         'user': get_database_setting(client, 'DB_USER', system.config[client]['path']),
     }
 
@@ -34,8 +38,8 @@ def get_database_setting(client, name, file):
     :return:
     """
     return mode.run_command(
-        helper.get_command(client, 'sed') + f' -n "s/define( *\'{name}\', *\'\([^\']*\)\'.*/\\1/p" {file}',
+        helper.get_command(client, 'sed') +
+        f' -n "s/define( *\'{name}\', *\'\([^\']*\)\'.*/\\1/p" {file}',
         client,
         True
     ).replace('\n', '')
-
